@@ -63,9 +63,8 @@ void DisplayIntro::start()
     mTimer->start(50);
 
     // Stop all card sprites
-    for (int i = 0; i < mCards.size(); i++)
-    {
-        mCards[i]->stop();
+    for (CardSprite *sprite : std::as_const(mCards)) {
+        sprite->stop();
     }
 }
 
@@ -94,6 +93,8 @@ void DisplayIntro::loop()
         QString s2 = i18nc("Title of the game - line 2", "for");
         QString s3 = i18nc("Title of the game - line 3", "K D E");
 
+        mSprites.reserve(6);
+
         // Text sprite title foreground
         TextSprite *text1a = new TextSprite(s1, QStringLiteral("name-front"), mTheme, scene());
         mSprites.append(text1a);
